#ifndef NT2_INCLUDE_FUNCTIONS_GT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_GT_HPP_INCLUDED

#include <nt2/operator/include/functions/gt.hpp>

#endif
